.. _lab_account:

Account
========

To use qBraid Lab, you must first sign in or create an account at `account.qbraid.com <https://account.qbraid.com>`_.

Add access key
---------------

.. |accountProfile| image:: ../_static/account/account_profile_details.png
    :width: 50%
    :target: javascript:void(0);

.. |submit| image:: ../_static/account/account_access_key.png
    :width: 45%
    :target: javascript:void(0);

Use the following steps to redeem qBraid credits and/or gain access to premium features
of qBraid Lab using an access key or promotional code:

1. Sign in to `account.qbraid.com <https://account.qbraid.com>`_.

2. Click on the account icon in the top right, and select **Profile**.

3. Open the **Account Details** tab.

|accountProfile|

4. Scroll down to **Add an Access Key**, enter your key or promo-code, and click **Submit**.

|submit|

*Congrats!* Your new credits and/or permissions have now been added to your account.

.. seealso::
    
    - `Using access codes to connect to quantum devices on qBraid | Demo <https://youtu.be/K4vb2fzmSZQ>`_
